
What's new here?
----------------

At first glance, Isomer looks like just another web application platform.

In contrast to most available systems though, Isomer works using a component
based frontend and backend architecture.

This enables every installation to install, activate and use only the modules relevant
for the local group of users.

Also, communication between clients and the backend has been streamlined
and minimized by relying on Websockets.